@@ -1,6 +1,9 @@
 #![deny(warnings)]
 use ultron::editor;
 use ultron::editor::Editor;
+
+#[allow(unused)]
+use ultron::sauron;
 use ultron::sauron::jss::jss;
 use ultron::sauron::prelude::*;
 use ultron::sauron::wasm_bindgen::JsCast;
@@ -108,10 +111,10 @@ impl Application<Msg> for App {
                 let effects = self
                     .editor
                     .update(editor::Msg::Mousemove(client_x, client_y));
-                Cmd::from(effects.localize(Msg::EditorMsg)).measure()
+                Cmd::from(effects.localize(Msg::EditorMsg))
             }
             Msg::Keydown(ke) => {
-                self.editor.update(editor::Msg::Keydown(ke));
+                self.editor.update(editor::Msg::WindowKeydown(ke));
                 Cmd::none().measure()
             }
             Msg::NoOp => Cmd::none().no_render(),
@@ -128,16 +131,21 @@ impl Application<Msg> for App {
     }
 }
 
+/*
 #[cfg(target_arch = "wasm32")]
 #[cfg(feature = "wee_alloc")]
 #[global_allocator]
 static ALLOC: wee_alloc::WeeAlloc = wee_alloc::WeeAlloc::INIT;
+*/
 
 #[cfg(target_arch = "wasm32")]
 #[wasm_bindgen(start)]
 pub fn main() {
     console_log::init_with_level(log::Level::Trace).unwrap();
-    console_error_panic_hook::set_once();
     log::trace!("starting ultron..");
-    Program::mount_to_body(App::new());
+    console_error_panic_hook::set_once();
+    let app_container = sauron::document()
+        .get_element_by_id("app_container")
+        .expect("must have the app_container in index.html");
+    Program::replace_mount(App::new(), &app_container);
 }
